import errno
import os
from pkg_resources import resource_listdir, resource_filename


def find(filename, parent="data", ext="csv"):
    """Find filepath to a resource within this package"""

    if "." not in filename:
        filename += ext
        print(f"No file extension specified; trying to load {filename}.")

    if filename not in resource_listdir(__name__, parent):
        raise FileNotFoundError(errno.ENOENT, os.strerror(errno.ENOENT), filename)

    file_path = resource_filename(__name__, f"{parent}/{filename}")

    return file_path



import pandas as pd

from .resources import find


def load_penguins():
    """Return Chinstrip and Adelie penguins from the Palmer penguins dataset."""
    file_path = find("penguins.csv")
    penguins = pd.read_csv(file_path)

    penguin_species = dict(tuple(penguins.groupby("species")))
    penguin_species = {
        species: data.reset_index(drop=True)
        for species, data in penguin_species.items()
    }

    return penguin_species["Chinstrap"], penguin_species["Adelie"]


def load_taxis():
    """Return subset of taxis dataset, as amended from the seaborn package."""
    file_path = find("taxis.csv")
    return pd.read_csv(file_path, skiprows=2)


def load_movies():
    """Return the IMDB movies DataFrame."""
    file_path = find("movies.zip")
    return pd.read_csv(file_path)



from shutil import copyfile

from .resources import find


def populate_example(filename):
    """Copy example from package resources to current working directory."""
    file_path = find(filename, "examples")
    copyfile(file_path, filename)
    print(f"\nCreated file {filename} in current directory.\n")


def get_dirty():
    """Copy the dirty script example to the user's current directory."""
    populate_example("script-dirty.py")


def get_messy():
    """Copy the messy script example to the user's current directory."""
    populate_example("script-messy.py")


def get_test():
    """Copy the test function to the user's current directory."""
    populate_example("test_forecast.py")
